#include <iostream>
#include <fstream>
#include <sstream>
#include <iomanip>
#include <vector>
#include <tuple>
#include <string>
#include <cmath>
#include <cassert>
#include <cstdlib>
#include <algorithm>
#include <iterator>
#include <numeric>
#include <stack>
#include <set>
#include <unordered_set>

using namespace std;

extern int rand_seed;

// --------------------------------------------------------------------------

// *Really* minimal PCG32 code / (c) 2014 M.E. O'Neill / pcg-random.org
// Licensed under Apache License 2.0 (NO WARRANTY, etc. see website)
typedef struct { uint64_t state;  uint64_t inc; } pcg32_random_t;

#define PCG32_INITIALIZER   { 0x853c49e6748fea9bULL, 0xda3e39cb94b95bdbULL }
static pcg32_random_t pcg32_global = PCG32_INITIALIZER;

uint32_t pcg32_random_r(pcg32_random_t* rng)
{
    uint64_t oldstate = rng->state;
    // Advance internal state
    rng->state = oldstate * 6364136223846793005ULL + (rng->inc|1);
    // Calculate output function (XSH RR), uses old state for max ILP
    uint32_t xorshifted = ((oldstate >> 18u) ^ oldstate) >> 27u;
    uint32_t rot = oldstate >> 59u;
    return (xorshifted >> rot) | (xorshifted << ((-rot) & 31));
}

uint32_t pcg32_random()
{
    return pcg32_random_r(&pcg32_global);
}

void pcg32_srandom_r(pcg32_random_t* rng, uint64_t initstate, uint64_t initseq)
{
    rng->state = 0U;
    rng->inc = (initseq << 1u) | 1u;
    pcg32_random_r(rng);
    rng->state += initstate;
    pcg32_random_r(rng);
}

void pcg32_srandom(uint64_t seed, uint64_t seq)
{
    pcg32_srandom_r(&pcg32_global, seed, seq);
}

//     Generate a uniformly distributed number, r, where 0 <= r < bound
uint32_t pcg32_boundedrand_r(pcg32_random_t* rng, uint32_t bound)
{
    uint32_t threshold = -bound % bound;
    for (;;) {
        uint32_t r = pcg32_random_r(rng);
        if (r >= threshold)
            return r % bound;
    }
}

uint32_t pcg32_boundedrand(uint32_t bound)
{
  return pcg32_boundedrand_r(&pcg32_global, bound);
}

uint64_t pcg64_random()
{
  return (((uint64_t)pcg32_random()) << 32) | ((uint64_t)pcg32_random());
}

uint64_t pcg64_boundedrand(uint64_t bound)
{
  uint64_t threshold = -bound % bound;
  for (;;) {
    uint64_t r = pcg64_random();
    if (r >= threshold)
      return r % bound;
  }
}

// --------------------------------------------------------------------------


int random_value(int i, int j) {
  return i + pcg32_boundedrand(j - i + 1);
}

int random_index(int j) {
  return random_value(0, j-1);
}

long long random_value(long long i, long long j) {
  return i + pcg64_boundedrand(j - i + 1);
}

unsigned long random_value_ul(unsigned long i, unsigned long j) {
  return i + pcg32_boundedrand(j - i + 1);
}

unsigned long long random_value_ull(unsigned long long i, unsigned long long j) {
  return i + pcg64_boundedrand(j - i + 1);
}

double random_value(double i, double j) {
  double x = (double)pcg32_random() / (double)(numeric_limits<uint32_t>::max());
  return i + x * (j - i);
}

bool random_bool(int positive = 1, int total = 2) {
  return random_value(1, total) <= positive;
}

int random_around(int i, double percent = 0.2) {
  return random_value((int)round((1 - percent) * i),
		      (int)round((1 + percent) * i));
}

int random_around_up(int i, double percent = 0.2) {
  return random_value(i, (int)round((1 + percent) * i));
}

int random_around_down(int i, double percent = 0.2) {
  return random_value((int)round((1 - percent) * i), i);
}

template <class T>
vector<T> random_array(int n, T min, T max) {
  vector<T> result(n);
  for (int i = 0; i < n; i++)
    result[i] = random_value(min, max);
  return result;
}

vector<unsigned long> random_array_ull(int n, unsigned long min, unsigned long max) {
  vector<unsigned long> result(n);
  for (int i = 0; i < n; i++)
    result[i] = random_value_ul(min, max);
  return result;
}

vector<unsigned long long> random_array_ull(int n, unsigned long long min, unsigned long long max) {
  vector<unsigned long long> result(n);
  for (int i = 0; i < n; i++)
    result[i] = random_value_ull(min, max);
  return result;
}

vector<int> random_sorted_array(int n, int min, int dmin, int dmax) {
  vector<int> result(n);
  result[0] = min;
  for (int i = 1; i < n; i++)
    result[i] = result[i-1] + random_value(dmin, dmax);
  return result;
}

vector<double> random_sorted_array(int n, double min, double dmin, double dmax) {
  vector<double> result(n);
  result[0] = min;
  for (int i = 1; i < n; i++)
    result[i] = result[i-1] + random_value(dmin, dmax);
  return result;
}

string random_string_alpha_(int from, int to, int numLetters = 26) {
  int n = random_value(from, to);
  string rez(n, ' ');
  for (int i = 0; i < n; i++)
    rez[i] = (random_value(0, 1) ? 'a' : 'A') + random_value(0, numLetters - 1);
  return rez;
}

string random_string_alpha(int n, int numLetters = 26) {
  return random_string_alpha_(n, n, numLetters);
}

string random_string_lower(int n, int numLetters = 26) {
  string rez(n, ' ');
  for (int i = 0; i < n; i++)
    rez[i] = 'a' + random_value(0, numLetters - 1);
  return rez;
}

string random_string_upper(int n, int numLetters = 26) {
  string rez(n, ' ');
  for (int i = 0; i < n; i++)
    rez[i] = 'A' + random_value(0, numLetters - 1);
  return rez;
}

string random_string_digits(int n, int numLetters = 10) {
  string rez(n, ' ');
  rez[0] = '0' + random_value(1, numLetters - 1);
  for (int i = 1; i < n; i++)
    rez[i] = '0' + random_value(0, numLetters - 1);
  return rez;
}

string random_sentence(int words_from = 2, int words_to = 10,
                       int word_length_from = 1, int word_length_to = 10) {
  int num_words = random_value(words_from, words_to);
  string rez;
  for (int i = 0; i < num_words; i++) {
    string word = random_string_lower(random_value(word_length_from, word_length_to));
    if (i == 0 || random_value(1, 4) == 1)
      word[0] = toupper(word[0]);
    rez += word;
    if (i == num_words - 1) {
      string interp = ".!?";
      rez += interp[random_value(0, 2)];
    } else {
      if (random_value(1, 5) == 1)
        rez += ",";
      rez += " ";
    }
  }
  return rez;
}

vector<int> sizes(int num_OK, int OK_size,
		  int num_TLE, int TLE_size) {
  vector<int> result;
  result.reserve(num_OK + num_TLE);
  for (int i = 0; i < num_OK; i++)
    result.push_back(random_around(OK_size, 0.2));
  for (int i = 0; i < num_TLE; i++)
    result.push_back(random_around_up(TLE_size, 0.2));
  return result;
}

vector<int> sizes_n(int num_OK, int num_TLE) {
  const int OK_size = 100;
  const int TLE_size = 20000;
  return sizes(num_OK, OK_size, num_TLE, TLE_size);
}

vector<int> sizes_n2(int num_OK, int num_TLE) {
  const int OK_size = 50;
  const int TLE_size = 2000;
  return sizes(num_OK, OK_size, num_TLE, TLE_size);
}

vector<int> sizes_n3(int num_OK, int num_TLE) {
  const int OK_size = 10;
  const int TLE_size = 100;
  return sizes(num_OK, OK_size, num_TLE, TLE_size);
}

vector<int> sizes_nlogn(int num_OK, int num_TLE) {
  const int OK_size = 100;
  const int TLE_size = 20000;
  return sizes(num_OK, OK_size, num_TLE, TLE_size);
}

template <class T>
void print_array(const vector<T>& a, ostream& tin, bool doNotPrintSize = false) {
  if (!doNotPrintSize)
    tin << a.size() << endl;
  for (auto x : a)
    tin << x << endl;
}

void print_array(const vector<double>& a, ostream& tin, bool doNotPrintSize, int prec) {
  if (!doNotPrintSize)
    tin << a.size() << endl;
  for (int i = 0; i < a.size(); i++)
    tin << setprecision(prec) << fixed << showpoint << a[i] << endl;
}


template <class T>
void print_array_inline(const vector<T>& a, ostream& tin, bool doNotPrintSize = false) {
  if (!doNotPrintSize)
    tin << a.size() << endl;
  for (int i = 0; i < a.size(); i++) {
    tin << a[i];
    if (i != a.size() - 1)
      tin << " ";
  }
  tin << endl;
}

void print_array_inline(const vector<double>& a, ostream& tin, bool doNotPrintSize, int prec) {
  if (!doNotPrintSize)
    tin << a.size() << endl;
  for (int i = 0; i < a.size(); i++) {
    tin << setprecision(prec) << fixed << showpoint << a[i];
    if (i != a.size() - 1)
      tin << " ";
  }
  tin << endl;
}


void print_random_time(ostream& out) {
  int h, m, s;
  h = random_value(0, 23);
  out << h << endl;
  m = random_value(0, 59);
  out << m << endl;
  s = random_value(0, 59);
  out << s << endl;
}

void print_random_angle(ostream& out) {
  int st = random_value(0, 359);
  int min = random_value(0, 59);
  int sek = random_value(0, 59);
  out << st << endl;
  out << min << endl;
  out << sek << endl;
}

// provera da li je data godina prestupna
bool isLeap(int year) {
  // year je prestupna ako je deljiva sa 4 i nije deljiva sa 100,
  // ili ako je deljiva sa 400
  return (year % 4 == 0 && year % 100 != 0) || (year % 400) == 0;
}

// broj dana u datom mesecu date godine
int daysInMonth(int month, int year) {
  switch (month) {
    // januar, mart, maj, jul, avgust, oktobar, decembar
  case 1: case 3: case 5: case 7: case 8: case 10: case 12:
    return 31;
    // april, jun, septembar, novembar
  case 4: case 6: case 9: case 11:
    return 30;
    // februar
  case 2:
    return isLeap(year) ? 29 : 28;
  }
  return 0;
}

tuple<int, int, int> random_date(int yearFrom = 1900, int yearTo = 2100) {
  int y = random_value(yearFrom, yearTo);
  int m = random_value(1, 12);
  int d = random_value(1, daysInMonth(m, y));
  return make_tuple(y, m, d);
}

vector<pair<int, int>> random_tree(int n, int deg = -1) {
  if (deg == -1)
    deg = n;
  vector<int> numChildren(n, 0);
  vector<pair<int, int>> edges;
  for (int i = 1; i <= n-1; i++) {
    while (true) {
      int parent = random_value(0, i-1);
      if (numChildren[parent] == deg)
        continue;
      edges.emplace_back(parent, i);
      numChildren[parent]++;
      break;
    }
  }
  return edges;
}

vector<pair<int, int>> random_connected_undirected_graph(int n, int m) {
  assert(n-1 <= m && m <= n*(n-1) / 2);
  cout << n << " " << m << endl;

  /*
  auto code = [](int i, int j) {
                return j*(j-1)/2 + i;
              };
  auto decode = [](int k) {
                  int j = 0;
                  while (j*(j+1)/2 <= k)
                    j++;
                  int i = k - (j * (j-1)) / 2;
                  return make_pair(i, j);
                };
  */
  
  // obavezno ukljucujemo sve grane jednog nasumicnog drveta (sto obezbedjuje povezanost)
  vector<pair<int, int>> tree = random_tree(n);

  if (m < n*(n-1) / 4) {
    cout << "Include " << m << " edges" << endl;
    set<pair<int, int>> include_edges(begin(tree), end(tree));
    while (include_edges.size() < m) {
      int j = random_value(0, n-1);
      int i = random_value(0, j);
      include_edges.emplace(i, j);
    }
    vector<pair<int, int>> graph(begin(include_edges), end(include_edges));
    return graph;
  } else {
    cout << "Exclude " << n*(n-1)/2 - m << " edges" << endl; 
    set<pair<int, int>> tree_edges(begin(tree), end(tree));
    set<pair<int, int>> exclude_edges;
    while (exclude_edges.size() < n*(n-1)/2 - m) {
      int j = random_value(0, n-1);
      int i = random_value(0, j);
      if (tree_edges.find(make_pair(i, j)) == tree_edges.end())
        exclude_edges.emplace(i, j);
    }
    vector<pair<int, int>> graph;
    for (int j = 1; j < n; j++)
      for (int i = 0; i < j; i++)
        if (exclude_edges.find(make_pair(i, j)) == exclude_edges.end())
          graph.emplace_back(i, j);
    return graph;
  }
}

// orijentise grane drveta u skladu sa datim korenom
vector<pair<int, int>> rooted_tree(const vector<pair<int, int>>& tree,
                                   int n, int root) {
  vector<pair<int, int>> result;
  result.reserve(tree.size());
  vector<vector<int>> nbr(n);
  for (const auto& p : tree) {
    nbr[p.first].push_back(p.second);
    nbr[p.second].push_back(p.first);
  }
  vector<bool> visited(n);
  stack<int> st;
  st.push(root);
  visited[root] = true;
  while (!st.empty()) {
    int c = st.top(); st.pop();
    for (int s : nbr[c])
      if (!visited[s]) {
        st.push(s);
        visited[s] = true;
        result.emplace_back(c, s);
      }
  }
  return result;
}

vector<pair<int, int>> random_connected_directed_graph(int n, int m, int root) {
  assert(n-1 <= m && m <= n*n);
  assert(0 <= root && root < n);
  cout << n << " " << m << endl;

  // da li je grana (i, j) iskljucena iz grafa
  vector<tuple<bool, int, int>> edges(n*n);
  for (int j = 0; j < n; j++)
    for (int i = 0; i < n; i++)
      edges[j*n + i] = make_tuple(true, i, j);

  // obavezno ukljucujemo sve grane jednog nasumicnog drveta (sto obezbedjuje povezanost)
  vector<pair<int, int>> tree = random_tree(n);
  vector<pair<int, int>> graph = rooted_tree(tree, n, root);
  for (const auto& p : graph) {
    int i, j;
    tie(i, j) = p;
    get<0>(edges[j*n + i]) = false;
  }
  // pomeramo grane drveta na pocetak niza
  auto b = begin(edges), e = end(edges);
  partition(b, e, [](const tuple<bool, int, int>& t) {return !get<0>(t); });


  // ukljucujemo dodatnih nasumicno odabranih m - n grana
  random_shuffle(next(b, n-1), e);
  int numEdges = n-1;
  auto it = next(b, n-1);
  while (numEdges < m) {
    if (get<1>(*it) != get<2>(*it)) {
      graph.emplace_back(get<1>(*it), get<2>(*it));
      numEdges++;
    }
    it++;
  }
  
  return graph;
}

vector<pair<int, int>> random_directed_graph(int n, int m,
                                             bool allow_loops = false) {
  int max = n*n-(allow_loops ? 0 : n);
  assert(0 <= m && m < max);
  vector<int> nodes(max);
  int k = 0;
  for (int i = 0; i < n; i++)
    for (int j = 0; j < n; j++)
      if (i != j)
        nodes[k++] = n*i+j;
  // random_shuffle is too slow - shuffle only to the initial part
  for (int i = 0; i < m; i++)
    swap(nodes[i], nodes[random_value(i, max-1)]);
  vector<pair<int, int>> graph(m);
  k = 0;
  for (int i = 0; i < m; i++)
    graph[k++] = make_pair(nodes[i] / n,  nodes[i] % n);
  return graph;
}

vector<pair<int, int>> random_directed_acyclic_graph(int n, int m) {
  vector<int> order(n);
  iota(begin(order), end(order), 0);
  random_shuffle(begin(order), end(order));
  vector<pair<int, int>> nodes(n*(n-1)/2);
  for (int j = 1; j < n; j++)
    for (int i = 0; i < j; i++) {
      nodes[j*(j-1)/2 + i] = make_pair(i, j);
    }
  // random_shuffle is too slow - shuffle only to the initial part
  for (int i = 0; i < m; i++)
    swap(nodes[i], nodes[random_value(i, nodes.size()-1)]);
  vector<pair<int, int>> result;
  for (int i = 0; i < m; i++)
    result.emplace_back(order[nodes[i].first], order[nodes[i].second]);
  return result;
}

extern int test_count;
extern string naziv_zadatka;

void gen_test(int i, ostream &tin); 

void gen_tests(string data_folder, int test_count) {
  for(int i=1;  i <= test_count; i++) {
    ofstream tin;
    stringstream buf;
    buf << setw(2) << setfill('0') << i;
    string file = data_folder + "/" + naziv_zadatka + "_" + buf.str();
    string inFile =  file + ".in";
    tin.open(inFile.c_str());
    cout << "INFO: generating test " << i << "..." << endl;
    gen_test(i, tin);
    tin.close();
    string outFile = file + ".out";
    string command = naziv_zadatka + ".exe" + " < " + inFile + " > " + outFile;
#ifdef __unix__
    command = "./" + command;
#endif
    assert(system(command.c_str()) == 0);
  }
}

int main(int argc, char* argv[]) {
  ios_base::sync_with_stdio(false);
  pcg32_srandom(rand_seed, 12345);
  if(argc != 2)
    cerr << "Program ocekuje argumete: <izlazni folder>";
  else
    gen_tests(argv[1], test_count);
}

